@@ -3,37 +3,36 @@ from .control import Control
 
 class SpinButton(Control):
     def __init__(self, label=None, id=None, value=None, min=None, max=None, step=None,
-            icon=None, data=None, onchange=None,
+            icon=None, data=None, on_change=None,
             width=None, height=None, padding=None, margin=None,
             visible=None, disabled=None):
         Control.__init__(self, id=id,
             width=width, height=height, padding=padding, margin=margin,
-            visible=visible, disabled=disabled)
+            visible=visible, disabled=disabled, data=data)
         self.value = value
         self.label = label
         self.min = min
         self.max = max
         self.step = step
         self.icon = icon
-        self.data = data
-        self.onchange = onchange
+        self.on_change = on_change
 
-    def _getControlName(self):
+    def _get_control_name(self):
         return "spinbutton"
 
-# onchange
+# on_change
     @property
-    def onchange(self):
-        return None
+    def on_change(self):
+        return self._get_event_handler("change")
 
-    @onchange.setter
-    def onchange(self, handler):
+    @on_change.setter
+    def on_change(self, handler):
         self._add_event_handler("change", handler)
 
 # value
     @property
     def value(self):
-        return self._get_attr("value")
+        return self._get_attr("value", data_type="float")
 
     @value.setter
     def value(self, value):
@@ -86,13 +85,4 @@ class SpinButton(Control):
 
     @icon.setter
     def icon(self, value):
-        self._set_attr("icon", value)
-
-# data
-    @property
-    def data(self):
-        return self._get_attr("data")
-
-    @data.setter
-    def data(self, value):
-        self._set_attr("data", value)
\ No newline at end of file
+        self._set_attr("icon", value)
\ No newline at end of file
